Module: EffectiveResources

Includes:
EffectiveGem
Defined in:
lib/effective_resources.rb,
lib/effective_resources/engine.rb,
lib/effective_resources/version.rb,
lib/generators/effective_resources/install_generator.rb

Defined Under Namespace

Modules: Generators Classes: Engine

Constant Summary collapse

MAILER_SUBJECT_PROC =
Proc.new { |action, subject, resource, opts = {}| subject }
VERSION =
'2.8.2'.freeze

Constants included from EffectiveGem

EffectiveGem::EXCLUDED_GETTERS

Class Method Summary collapse

Class Method Details

.advance_date(date, business_days: 1, holidays: [:ca, :observed]) ⇒ Object



114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/effective_resources.rb', line 114

def self.advance_date(date, business_days: 1, holidays: [:ca, :observed])
  raise('business_days must be an integer <= 365') unless business_days.kind_of?(Integer) && business_days <= 365

  business_days.times do
    loop do
      date = date + 1.day
      break if business_day?(date, holidays: holidays)
    end
  end

  date
end

.authorize!(controller, action, resource) ⇒ Object



32
33
34
# File 'lib/effective_resources.rb', line 32

def self.authorize!(controller, action, resource)
  raise Effective::AccessDenied.new('Access Denied', action, resource) unless authorized?(controller, action, resource)
end

.authorized?(controller, action, resource) ⇒ Boolean

Returns:

  • (Boolean)


19
20
21
22
23
24
25
26
27
28
29
30
# File 'lib/effective_resources.rb', line 19

def self.authorized?(controller, action, resource)
  @exceptions ||= [Effective::AccessDenied, (CanCan::AccessDenied if defined?(CanCan)), (Pundit::NotAuthorizedError if defined?(Pundit))].compact

  return !!authorization_method unless authorization_method.respond_to?(:call)
  controller = controller.controller if controller.respond_to?(:controller)

  begin
    !!(controller || self).instance_exec((controller || self), action, resource, &authorization_method)
  rescue *@exceptions
    false
  end
end

.best(name) ⇒ Object

This looks up the best class give the name If the Tenant is present, use those classes first.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/effective_resources.rb', line 75

def self.best(name)
  klass = if defined?(Tenant)
    ('::' + Tenant.module_name + '::' + name).safe_constantize ||
    ('::' + Tenant.module_name + '::Effective::' + name).safe_constantize
  end

  klass ||= begin
    ('::' + name).safe_constantize ||
    ('::Effective::' + name).safe_constantize
  end

  raise("unable to find best #{name}") if klass.blank?

  klass
end

.business_day?(date, holidays: [:ca, :observed]) ⇒ Boolean

Returns:

  • (Boolean)


127
128
129
130
# File 'lib/effective_resources.rb', line 127

def self.business_day?(date, holidays: [:ca, :observed])
  require 'holidays' unless defined?(Holidays)
  date.wday != 0 && date.wday != 6 && Holidays.on(date, *holidays).blank?
end

.clone_blob(blob, options = {}) ⇒ Object



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/effective_resources.rb', line 133

def self.clone_blob(blob, options = {})
  raise('expected an ActiveStorage::Blob') unless blob.kind_of?(ActiveStorage::Blob)

  atts = {
    filename: blob.filename,
    byte_size: blob.byte_size,
    checksum: blob.checksum,
    content_type: blob.content_type,
    metadata: blob.,
  }.merge(options)

  service = blob.service
  duplicate = ActiveStorage::Blob.create_before_direct_upload!(**atts)

  case service.class.name
  when 'ActiveStorage::Service::S3Service'
    bucket = service.bucket
    object = bucket.object(blob.key)
    object.copy_to(bucket.object(duplicate.key))
  when 'ActiveStorage::Service::DiskService'
    path = service.path_for(blob.key)
    duplicate_path = service.path_for(duplicate.key)
    FileUtils.mkdir_p(File.dirname(duplicate_path))
    FileUtils.ln(path, duplicate_path) if File.exist?(path)
  else
    raise "unknown storage service #{service.class.name}"
  end

  duplicate
end

.config_keys ⇒ Object



10
11
12
13
14
15
# File 'lib/effective_resources.rb', line 10

def self.config_keys
  [
    :authorization_method, :default_submits,
    :parent_mailer, :deliver_method, :mailer_layout, :mailer_sender, :mailer_admin, :mailer_subject
  ]
end

.default_submits ⇒ Object



36
37
38
# File 'lib/effective_resources.rb', line 36

def self.default_submits
  (['Save', 'Continue', 'Add New'] & Array(config.default_submits)).inject({}) { |h, v| h[v] = true; h }
end

.deliver_method ⇒ Object

Mailer Settings These serve as the default mailer settings for all effective_* gems They can be overriden on a per-gem basis.



43
44
45
46
47
48
# File 'lib/effective_resources.rb', line 43

def self.deliver_method
  return config[:deliver_method] if config[:deliver_method].present?

  rails = Rails.application.config
  (rails.respond_to?(:active_job) && rails.active_job.queue_adapter) ? :deliver_later : :deliver_now
end

.et(resource, attribute = nil) ⇒ Object



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/effective_resources.rb', line 183

def self.et(resource, attribute = nil)
  if resource.respond_to?(:datatable_name)
    resource.datatable_name
  elsif resource.respond_to?(:model_name) == false
    value = I18n.t(resource)
    raise("Missing translation: #{resource}") if value.start_with?('translation missing:')
    value
  elsif attribute.blank?
    resource.model_name.human
  elsif resource.respond_to?(:human_attribute_name)
    resource.human_attribute_name(attribute)
  else
    resource.class.human_attribute_name(attribute)
  end
end

.etd(resource, attribute = nil) ⇒ Object



199
200
201
# File 'lib/effective_resources.rb', line 199

def self.etd(resource, attribute = nil)
  et(resource, attribute).downcase
end

.ets(resource, attribute = nil) ⇒ Object



203
204
205
# File 'lib/effective_resources.rb', line 203

def self.ets(resource, attribute = nil)
  et(resource, attribute).pluralize
end

.etsd(resource, attribute = nil) ⇒ Object



207
208
209
# File 'lib/effective_resources.rb', line 207

def self.etsd(resource, attribute = nil)
  et(resource, attribute).pluralize.downcase
end

.mailer_admin ⇒ Object



67
68
69
# File 'lib/effective_resources.rb', line 67

def self.mailer_admin
  config[:mailer_admin] || raise('effective resources mailer_admin missing. Add it to config/initializers/effective_resources.rb')
end

.mailer_layout ⇒ Object



55
56
57
# File 'lib/effective_resources.rb', line 55

def self.mailer_layout
  config[:mailer_layout] || 'effective_mailer_layout'
end

.mailer_sender ⇒ Object



63
64
65
# File 'lib/effective_resources.rb', line 63

def self.mailer_sender
  config[:mailer_sender] || raise('effective resources mailer_sender missing. Add it to config/initializers/effective_resources.rb')
end

.mailer_subject ⇒ Object



59
60
61
# File 'lib/effective_resources.rb', line 59

def self.mailer_subject
  config[:mailer_subject] || MAILER_SUBJECT_PROC
end

.parent_mailer_class ⇒ Object



50
51
52
53
# File 'lib/effective_resources.rb', line 50

def self.parent_mailer_class
  return config[:parent_mailer].constantize if config[:parent_mailer].present?
  '::ApplicationMailer'.safe_constantize || 'ActionMailer::Base'.constantize
end

.replace_nested_attributes(attributes) ⇒ Object



177
178
179
180
181
# File 'lib/effective_resources.rb', line 177

def self.replace_nested_attributes(attributes)
  attributes.reject { |k, values| truthy?(values[:_destroy]) }.inject({}) do |h, (key, values)|
    h[key] = values.reject { |k, v| k == 'id' || k == '_destroy' }; h
  end
end

.transaction(resource = nil, &block) ⇒ Object



164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/effective_resources.rb', line 164

def self.transaction(resource = nil, &block)
  raise('expected a block') unless block_given?

  if resource.respond_to?(:transaction)
    resource.transaction { yield }
  elsif resource.class.respond_to?(:transaction)
    resource.class.transaction { yield }
  else
    ActiveRecord::Base.transaction { yield }
  end

end

.truthy?(value) ⇒ Boolean

Returns:

  • (Boolean)


106
107
108
109
110
111
112
# File 'lib/effective_resources.rb', line 106

def self.truthy?(value)
  if defined?(::ActiveRecord::ConnectionAdapters::Column::TRUE_VALUES)  # Rails <5
    ::ActiveRecord::ConnectionAdapters::Column::TRUE_VALUES.include?(value)
  else
    ::ActiveRecord::Type::Boolean.new.cast(value)
  end
end

.with_resource_enumerator(&block) ⇒ Object

Used by streaming CSV export in datatables



92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/effective_resources.rb', line 92

def self.with_resource_enumerator(&block)
  raise('expected a block') unless block_given?

  tenant = Tenant.current if defined?(Tenant)

  if tenant
    Enumerator.new do |enumerator|
      Tenant.as(tenant) { yield(enumerator) }
    end
  else
    Enumerator.new { |enumerator| yield(enumerator) }
  end
end